summaryrefslogtreecommitdiff
path: root/include/llvm/CodeGen/SelectionDAGISel.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2010-12-23 17:24:32 +0000
committerChris Lattner <sabre@nondot.org>2010-12-23 17:24:32 +0000
commit29d8f0cae425f1bba583565227eaebf58f26ce73 (patch)
tree65c8d6ff1456189d73251f65786f2546514c516a /include/llvm/CodeGen/SelectionDAGISel.h
parenta4359be0328a91971c486b06892c742de1fa0f2b (diff)
downloadllvm-29d8f0cae425f1bba583565227eaebf58f26ce73.tar.gz
llvm-29d8f0cae425f1bba583565227eaebf58f26ce73.tar.bz2
llvm-29d8f0cae425f1bba583565227eaebf58f26ce73.tar.xz
flags -> glue for selectiondag
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@122509 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/CodeGen/SelectionDAGISel.h')
-rw-r--r--include/llvm/CodeGen/SelectionDAGISel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/CodeGen/SelectionDAGISel.h b/include/llvm/CodeGen/SelectionDAGISel.h
index e4f60d66e2..e5204db5cd 100644
--- a/include/llvm/CodeGen/SelectionDAGISel.h
+++ b/include/llvm/CodeGen/SelectionDAGISel.h
@@ -110,7 +110,7 @@ public:
OPC_RecordChild0, OPC_RecordChild1, OPC_RecordChild2, OPC_RecordChild3,
OPC_RecordChild4, OPC_RecordChild5, OPC_RecordChild6, OPC_RecordChild7,
OPC_RecordMemRef,
- OPC_CaptureFlagInput,
+ OPC_CaptureGlueInput,
OPC_MoveChild,
OPC_MoveParent,
OPC_CheckSame,
@@ -140,12 +140,12 @@ public:
OPC_EmitNodeXForm,
OPC_EmitNode,
OPC_MorphNodeTo,
- OPC_MarkFlagResults,
+ OPC_MarkGlueResults,
OPC_CompleteMatch
};
enum {
- OPFL_None = 0, // Node has no chain or flag input and isn't variadic.
+ OPFL_None = 0, // Node has no chain or glue input and isn't variadic.
OPFL_Chain = 1, // Node has a chain input.
OPFL_GlueInput = 2, // Node has a glue input.
OPFL_GlueOutput = 4, // Node has a glue output.